@@ -1,24 +1,21 @@
 #!/usr/bin/python
 """test the facility which enables usage of the with-statement
 
-:author: `Patrick Kanzler <patrick.kanzler@fablab.fau.de>`_
+:author: `Patrick Kanzler <dev@pkanzler.de>`_
 :organization: `python-escpos <https://github.com/python-escpos>`_
 :copyright: Copyright (c) 2016 `python-escpos <https://github.com/python-escpos>`_
-:license: GNU GPL v3
+:license: MIT
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-import escpos.printer as printer
 import escpos.escpos as escpos
+import escpos.printer as printer
 
 
 def test_with_statement():
-    """Use with statement"""
+    """Use with statement
+
+    .. todo:: Extend these tests as they don't really do anything at the moment"""
     dummy_printer = printer.Dummy()
     with escpos.EscposIO(dummy_printer) as p:
-            p.writelines('Some text.\n')
-    # TODO extend these tests as they don't really do anything at the moment
+        p.writelines("Some text.\n")
